==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/EmailEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class EmailEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRR8PmwHx5gkWImCCFKAtFlDbQSJTCyIDEg4QhFuWPtW8Vr3sdl9lxwN4ifwE6CnQaKjQhTUFDSIv4AQBS3i7Z3js+EQuDhL+2ZmZ2feq69QMhoujXgcMx0FKH3Bdrf39+/3R2KAt4QZaKkw1JD+Cg44Pai6k3ODcKXXsfTGmN5ohb4KAxFMsZsdmDf4xBNmKAQiXJxlDIxpdCfjZqwifaI6MZWn+uL7N+e5++ylAxArclekp6z/i5W9pNgBR7oI5+imI97weHBANrQMDshvzZ61PG7MPe6LQ3gKcx0oK65JDOHy/z850Uj4sUKobTzU3JU7riTMVYTNQeizUaSl8bkeDIVhR3bOIslEgjFsx+fSSwlKJUplhKLLkSMsWpfMOmep8wxRS/mtMMDE8upMMOaYwGyP9z2RUaobu3sixm0t+DWEZasdj5GTgYUuKAr6woweVciyCrOMCz0o6YiOyUDvz9Yf0Cjte/W3vq1gMv25Uv/09sub9knJBbp7ORc6taMUvtKhEhqlvXohbThC6TXuctXsQcUIjxY8WeC1HGPd8ZjM0X1LScyWzm5zMySJ0tznd+9XHn88BU4b5r2Qu21u8XeggkNNKYSeG6ubW4mjM8en6btovVFzSEkinL1uG1zvy8ClfG/EFMFaTgQTH/3Khx/17uut6RjO/xWeRVF6BGUZeDIQybaPFzl3u6vKiMgNs4XNW+GC/a8rpX4BZmGUezsEAAA=";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    private javax.swing.JTextArea $JTextArea1;
    private EmailEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource2 = new DataBindingListener(this, "$JTextArea1.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public EmailEditor() {
        super();
        $initialize();
    }

    public EmailEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JTextArea1.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource2);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JTextArea1.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText($JTextArea1, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JTextArea1.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource2);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JTextArea get$JTextArea1() {
        return $JTextArea1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("$JTextArea1.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JTextArea1
        $objectMap.put("$JTextArea1", $JTextArea1 = new javax.swing.JTextArea());
        $JTextArea1.setName("$JTextArea1");
        $JTextArea1.setColumns(15);
        $JTextArea1.setLineWrap(true);
        $JTextArea1.setWrapStyleWord(true);
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JTextArea1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/EmailEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class EmailEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRR8PmwHJ5gkWImCCFKAtKzpjSCRiQWRAQlHKMIN67tVvNZ9bHbfJUeD+An8BOhpkOioEAU1BQ3iLyBEQYt4e+f4bDgELs7S7sy82Zn36itUjIZLI54kTMchykCw3e39/fuDkXDxljCulgojDdmv5IDThwVvcm4QrvS7lt4c05vtKFBRKMIpdqsL8waf+MIMhUCEi7MM15hmb3LdSlSsT1QnpopUX3z/5jz3nr10ABJF7sr0lI1/sfKXlLvgSA/hHE064k2fhwdkQ8vwgPzW7Vnb58bc44E4hKcw14Wq4prEEC7//5NTjZSfKIT65kPNPbnjScJcQ7jqRgEbxVqagGt3KAw7svcslkykGMN2Ai79jKBUqlRFKHscOcKSdcmsc5Y5zxH1jN+OQkwtr80EY44JzPb4wBc5pZpREFasbDIG7e6JBLe14Ba1qCjjCzNS1B7L28vjLfWhomM6ptn9Pwt/QFdZ1Wu/VW0F09ufq41Pb7+86Zz0W6LZK4XQqfWk3JWOlNAo7ejFrNwYpd+8y1WrDzUjfNrtdHfXC4z1xtdkjuYtpwlbOrvNzZAkKnOf371fffzxFDgdmPcj7nW4xd+BGg41pRD5XqJubqWOzhyfpu+S9UalISWJcPa6LW9jIEOP8r2RUATrBRFMfAxqH340eq+3pmM4/1d4HkXlEVRl6MtQpIs+3uHCxV5QRsRelO9q0faW7H9DKfULH7QltzYEAAA=";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    protected javax.swing.JTextArea editor;
    private EmailEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource1 = new DataBindingListener(this, "editor.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public EmailEditor() {
        super();
        $initialize();
    }

    public EmailEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource1);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("editor.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText(editor, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource1);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    public javax.swing.JTextArea getEditor() {
        return editor;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("editor.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        createEditor();
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add(editor, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    protected void createEditor() {
        $objectMap.put("editor", editor = new javax.swing.JTextArea());
        editor.setName("editor");
        editor.setColumns(15);
        editor.setLineWrap(true);
        editor.setWrapStyleWord(true);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}
